@@ -1,13 +1,16 @@
 package XML::LibXML::Debugging;
 
 use 5.008;
-use base qw(XML::LibXML);
+use parent qw(XML::LibXML);
 use strict;
 
-use HTML::Entities qw(encode_entities_numeric);
+use HTML::HTML5::Entities qw(encode_entities_numeric);
 use XML::LibXML qw(:all);
 
-our $VERSION = '0.100';
+BEGIN {
+	$XML::LibXML::Debugging::AUTHORITY = 'cpan:TOBYINK';
+	$XML::LibXML::Debugging::VERSION   = '0.101';
+}
 
 sub XML::LibXML::Document::toDebuggingHash
 {
@@ -145,7 +148,7 @@ sub XML::LibXML::Attr::toDebuggingHash
 	if ($n->nodeType == XML_NAMESPACE_DECL)
 	{
 		return {
-			'type'    => 'Attribute (XMLNS)',
+			'type'    => 'Namespace Declaration',
 			'qname'   => $n->nodeName,
 			'prefix'  => $n->prefix,
 			'suffix'  => $n->getLocalName,
@@ -175,7 +178,7 @@ sub XML::LibXML::Attr::toClarkML
 			return sprintf("{%s}%s=\"%s\"",
 				$n->getNamespaceURI, $n->getLocalName, $n->getData);
 		}
-		return sprintf("{%s}XMLNS=\"%s\"",
+		return sprintf("{%s}xmlns=\"%s\"",
 			$n->getNamespaceURI, $n->getData);
 	}
 	
@@ -241,7 +244,7 @@ string of XML-like markup with explicit namespaces. The following XML:
 Might be represented as:
 
   <{http://example.com/1}foo
-       {http://www.w3.org/2000/xmlns/}XMLNS="http://example.com/1"
+       {http://www.w3.org/2000/xmlns/}xmlns="http://example.com/1"
        {http://www.w3.org/2000/xmlns/}bar="http://example.com/2"
        {http://example.com/2}baz="quux" />
 
@@ -254,7 +257,8 @@ Please report any bugs to L<http://rt.cpan.org/>.
 
 =head1 SEE ALSO
 
-L<XML::LibXML>.
+L<XML::LibXML>,
+L<XML::LibXML::Debugging>.
 
 =head1 AUTHOR
 
@@ -267,4 +271,10 @@ Copyright (C) 2009-2011 by Toby Inkster
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
+=head1 DISCLAIMER OF WARRANTIES
+
+THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
+WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
+MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+
 =cut
